def 列表_筛选_关键词保留(列表, 关键词):
    """
    保留列表中包含指定关键词的元素，并返回过滤后的新列表。

    参数:
        - 列表 (list): 包含字符串元素的列表。
        - 关键词 (str): 要保留的关键词。

    返回:
        - 过滤后的新列表 (list): 只包含包含指定关键词的元素的列表。如果处理过程中发生异常，则返回错误信息。

    示例:
        结果 = 列表_筛选_关键词保留(["apple", "banana", "cherry"], "a")
        print("过滤后的新列表:", 结果)
    """
    try:
        # 使用列表推导式过滤出包含关键词的元素
        过滤后的新列表 = [元素 for 元素 in 列表 if 关键词 in str(元素)]
        return 过滤后的新列表
    except Exception as e:
        # 捕获所有异常并返回错误信息
        return f"处理失败: {e}"