def excel_读取单元格(表格对象, 工作表名, 单元格):
    """
    参数:
    - 表格对象: 要读取单元格的表格对象
    - 工作表名: 要读取单元格的工作表名称
    - 单元格: 要读取的单元格的坐标，例如 'A1'

    返回值:
    - 如果成功读取单元格内容，则返回 单元格内容 ；如果读取失败，则返回 None
    """
    try:
        工作表 = 表格对象[工作表名]
        return 工作表[单元格].value
    except Exception:
        return None