def excel_修改单元格(表格对象, 工作表名, 单元格, 新值):
    """
    参数:
    - 表格对象: 要修改单元格的表格对象
    - 工作表名: 要修改单元格的工作表名称
    - 单元格: 要修改的单元格的坐标，例如 'A1'
    - 新值: 要设置的新值

    返回值:
    - 如果成功修改单元格内容，则返回 True ；如果修改失败，则返回 False
    """
    try:
        工作表 = 表格对象[工作表名]
        工作表[单元格] = 新值
        return True
    except Exception:
        return False