def 邮件POP3_批量删除邮件(服务器对象, 删除数量):
    """
    批量删除邮件。

    参数:
        - pop3_server: 已连接的 POP3 服务器对象。
        - 删除数量 (int): 要删除的邮件数量，默认从第一封邮件开始删除。

    返回:
        - 删除成功的邮件数量。

    示例:
    删除数量 = 邮件POP3_批量删除邮件(pop3_server, 5)
    print(f"成功删除 {删除数量} 封邮件")

     注意:
        - 删除邮件后，需要调用断开连接函数 `zfx.邮件pop3_断开连接(服务器对象)` 才会生效。
    """
    成功删除数量 = 0
    try:
        # 获取邮箱状态信息
        总邮件数量, 邮件大小 = 服务器对象.stat()

        # 遍历删除邮件
        for i in range(1, 删除数量 + 1):
            服务器对象.dele(i)
            成功删除数量 += 1
        return 成功删除数量
    except Exception:
        return 成功删除数量